@@ -6,6 +6,7 @@ from daft.daft import (
     AzureConfig,
     GCSConfig,
     IOConfig,
+    HTTPConfig,
     S3Config,
     S3Credentials,
     set_io_pool_num_threads,
@@ -52,6 +53,7 @@ __all__ = [
     "S3Credentials",
     "AzureConfig",
     "GCSConfig",
+    "HTTPConfig",
     "set_io_pool_num_threads",
     "DataCatalogType",
     "DataCatalogTable",
