@@ -288,3 +288,20 @@ class LogicalPlanBuilder:
             io_config,
         )
         return LogicalPlanBuilder(builder)
+
+    def write_lance(
+        self,
+        path: str | pathlib.Path,
+        mode: str,
+        io_config: IOConfig,
+        kwargs: dict | None,
+    ) -> LogicalPlanBuilder:
+        columns_name = self.schema().column_names()
+        builder = self._builder.lance_write(
+            str(path),
+            columns_name,
+            mode,
+            io_config,
+            kwargs,
+        )
+        return LogicalPlanBuilder(builder)
