@@ -8,13 +8,13 @@ import sys
 
 if sys.version_info < (3, 8):
     try:
-        import pickle5 as pickle  # noqa: F401
-        from pickle5 import Pickler  # noqa: F401
+        import pickle5 as pickle
+        from pickle5 import Pickler
     except ImportError:
-        import pickle  # noqa: F401
+        import pickle
 
         # Use the Python pickler for old CPython versions
-        from pickle import _Pickler as Pickler  # noqa: F401
+        from pickle import _Pickler as Pickler
 else:
     import pickle  # noqa: F401
 
