@@ -3,6 +3,8 @@ from __future__ import annotations
 import contextlib
 import math
 import pathlib
+import random
+import time
 from collections.abc import Callable, Generator
 from typing import IO, TYPE_CHECKING, Any, Union
 from uuid import uuid4
@@ -453,7 +455,7 @@ def write_tabular(
         format = pads.ParquetFileFormat()
         inflation_factor = execution_config.parquet_inflation_factor
         target_file_size = execution_config.parquet_target_filesize
-        opts = format.make_write_options(compression=compression)
+        opts = format.make_write_options(compression=compression, use_compliant_nested_type=False)
     elif file_format == FileFormat.Csv:
         format = pads.CsvFileFormat()
         opts = None
@@ -633,12 +635,14 @@ def write_iceberg(
 
     format = pads.ParquetFileFormat()
 
+    opts = format.make_write_options(compression="zstd", use_compliant_nested_type=False)
+
     _write_tabular_arrow_table(
         arrow_table=arrow_table,
         schema=file_schema,
         full_path=resolved_path,
         format=format,
-        opts=format.make_write_options(compression="zstd"),
+        opts=opts,
         fs=fs,
         rows_per_file=rows_per_file,
         rows_per_row_group=rows_per_row_group,
@@ -735,10 +739,10 @@ def write_deltalake(
     target_row_groups = max(math.ceil(size_bytes / target_row_group_size / inflation_factor), 1)
     rows_per_row_group = max(min(math.ceil(num_rows / target_row_groups), rows_per_file), 1)
 
-    opts = pads.ParquetFileFormat().make_write_options(use_compliant_nested_type=False)
-
     format = pads.ParquetFileFormat()
 
+    opts = format.make_write_options(use_compliant_nested_type=False)
+
     _write_tabular_arrow_table(
         arrow_table=arrow_batch,
         schema=None,
@@ -756,6 +760,23 @@ def write_deltalake(
     return MicroPartition.from_pydict({"data_file": Series.from_pylist(data_files, name="data_file", pyobj="force")})
 
 
+def write_lance(mp: MicroPartition, base_path: str, mode: str, io_config: IOConfig | None, kwargs: dict | None):
+    import lance
+
+    from daft.io.object_store_options import io_config_to_storage_options
+
+    io_config = get_context().daft_planning_config.default_io_config if io_config is None else io_config
+    storage_options = io_config_to_storage_options(io_config, base_path)
+
+    arrow_table = mp.to_arrow()
+
+    fragments = lance.fragment.write_fragments(arrow_table, base_path, mode, storage_options=storage_options, **kwargs)
+
+    mp = MicroPartition.from_pydict({"fragments": fragments})
+
+    return mp
+
+
 def _write_tabular_arrow_table(
     arrow_table: pa.Table,
     schema: pa.Schema | None,
@@ -786,17 +807,34 @@ def _write_tabular_arrow_table(
     else:
         basename_template = f"{uuid4()}-{{i}}.{format.default_extname}"
 
-    pads.write_dataset(
-        arrow_table,
-        schema=schema,
-        base_dir=full_path,
-        basename_template=basename_template,
-        format=format,
-        partitioning=None,
-        file_options=opts,
-        file_visitor=file_visitor,
-        use_threads=True,
-        existing_data_behavior="overwrite_or_ignore",
-        filesystem=fs,
-        **kwargs,
-    )
+    NUM_TRIES = 3
+    JITTER_MS = 2_500
+    MAX_BACKOFF_MS = 20_000
+
+    for attempt in range(NUM_TRIES):
+        try:
+            pads.write_dataset(
+                arrow_table,
+                schema=schema,
+                base_dir=full_path,
+                basename_template=basename_template,
+                format=format,
+                partitioning=None,
+                file_options=opts,
+                file_visitor=file_visitor,
+                use_threads=True,
+                existing_data_behavior="overwrite_or_ignore",
+                filesystem=fs,
+                **kwargs,
+            )
+            break
+        except OSError as e:
+            if "InvalidPart" not in str(e):
+                raise
+
+            if attempt == NUM_TRIES - 1:
+                raise OSError(f"Failed to retry write to {full_path}") from e
+            else:
+                jitter = random.randint(0, (2**attempt) * JITTER_MS)
+                backoff = min(MAX_BACKOFF_MS, jitter)
+                time.sleep(backoff / 1000)
