@@ -94,16 +94,13 @@ impl PyDaftExecutionConfig {
         num_preview_rows: Option<usize>,
         parquet_target_filesize: Option<usize>,
         parquet_target_row_group_size: Option<usize>,
-        parquet_max_open_files: Option<usize>,
-        parquet_max_rows_per_file: Option<usize>,
-        parquet_min_rows_per_group: Option<usize>,
-        parquet_max_rows_per_group: Option<usize>,
         parquet_inflation_factor: Option<f64>,
         csv_target_filesize: Option<usize>,
         csv_inflation_factor: Option<f64>,
         shuffle_aggregation_default_partitions: Option<usize>,
         read_sql_partition_size_bytes: Option<usize>,
         enable_aqe: Option<bool>,
+        enable_native_executor: Option<bool>,
     ) -> PyResult<PyDaftExecutionConfig> {
         let mut config = self.config.as_ref().clone();
 
@@ -137,18 +134,6 @@ impl PyDaftExecutionConfig {
         if let Some(parquet_target_row_group_size) = parquet_target_row_group_size {
             config.parquet_target_row_group_size = parquet_target_row_group_size;
         }
-        if let Some(parquet_max_open_files) = parquet_max_open_files {
-            config.parquet_max_open_files = parquet_max_open_files
-        }
-        if let Some(parquet_max_rows_per_file) = parquet_max_rows_per_file {
-            config.parquet_max_rows_per_file = parquet_max_rows_per_file;
-        }
-        if let Some(parquet_min_rows_per_group) = parquet_min_rows_per_group {
-            config.parquet_min_rows_per_group = parquet_min_rows_per_group;
-        }
-        if let Some(parquet_max_rows_per_group) = parquet_max_rows_per_group {
-            config.parquet_max_rows_per_group = parquet_max_rows_per_group;
-        }
         if let Some(parquet_inflation_factor) = parquet_inflation_factor {
             config.parquet_inflation_factor = parquet_inflation_factor;
         }
@@ -169,6 +154,9 @@ impl PyDaftExecutionConfig {
         if let Some(enable_aqe) = enable_aqe {
             config.enable_aqe = enable_aqe;
         }
+        if let Some(enable_native_executor) = enable_native_executor {
+            config.enable_native_executor = enable_native_executor;
+        }
 
         Ok(PyDaftExecutionConfig {
             config: Arc::new(config),
@@ -215,26 +203,6 @@ impl PyDaftExecutionConfig {
         Ok(self.config.parquet_target_row_group_size)
     }
 
-    #[getter]
-    fn get_parquet_max_open_files(&self) -> PyResult<usize> {
-        Ok(self.config.parquet_max_open_files)
-    }
-
-    #[getter]
-    fn get_parquet_max_rows_per_file(&self) -> PyResult<usize> {
-        Ok(self.config.parquet_max_rows_per_file)
-    }
-
-    #[getter]
-    fn get_parquet_min_rows_per_group(&self) -> PyResult<usize> {
-        Ok(self.config.parquet_min_rows_per_group)
-    }
-
-    #[getter]
-    fn get_parquet_max_rows_per_group(&self) -> PyResult<usize> {
-        Ok(self.config.parquet_max_rows_per_group)
-    }
-
     #[getter]
     fn get_parquet_inflation_factor(&self) -> PyResult<f64> {
         Ok(self.config.parquet_inflation_factor)
@@ -263,6 +231,10 @@ impl PyDaftExecutionConfig {
     fn enable_aqe(&self) -> PyResult<bool> {
         Ok(self.config.enable_aqe)
     }
+    #[getter]
+    fn enable_native_executor(&self) -> PyResult<bool> {
+        Ok(self.config.enable_native_executor)
+    }
 
     fn __reduce__(&self, py: Python) -> PyResult<(PyObject, (Vec<u8>,))> {
         let bin_data = bincode::serialize(self.config.as_ref())
