@@ -4,12 +4,14 @@ use std::fmt::Formatter;
 use serde::Deserialize;
 use serde::Serialize;
 
+use crate::HTTPConfig;
 use crate::{AzureConfig, GCSConfig, S3Config};
 #[derive(Clone, Default, Debug, Serialize, Deserialize, PartialEq, Eq, Hash)]
 pub struct IOConfig {
     pub s3: S3Config,
     pub azure: AzureConfig,
     pub gcs: GCSConfig,
+    pub http: HTTPConfig,
 }
 
 impl IOConfig {
@@ -27,6 +29,10 @@ impl IOConfig {
             "GCS config = {{ {} }}",
             self.gcs.multiline_display().join(", ")
         ));
+        res.push(format!(
+            "HTTP config = {{ {} }}",
+            self.http.multiline_display().join(", ")
+        ));
         res
     }
 }
@@ -38,8 +44,9 @@ impl Display for IOConfig {
             "IOConfig:
 {}
 {}
+{}
 {}",
-            self.s3, self.azure, self.gcs
+            self.s3, self.azure, self.gcs, self.http,
         )
     }
 }
