@@ -7,6 +7,8 @@ use serde::Serialize;
 #[derive(Clone, Default, Debug, Serialize, Deserialize, PartialEq, Eq, Hash)]
 pub struct GCSConfig {
     pub project_id: Option<String>,
+    pub credentials: Option<String>,
+    pub token: Option<String>,
     pub anonymous: bool,
 }
 
@@ -16,7 +18,7 @@ impl GCSConfig {
         if let Some(project_id) = &self.project_id {
             res.push(format!("Project ID = {}", project_id));
         }
-        res.push(format!("Anoynmous = {}", self.anonymous));
+        res.push(format!("Anonymous = {}", self.anonymous));
         res
     }
 }
