@@ -123,6 +123,47 @@ impl Schema {
         // Begin the header.
         res.push_str("<thead><tr>");
 
+        // Add header for column name and type
+        res.push_str("<th style=\"text-wrap: nowrap; max-width:192px; overflow:auto; text-align:left\">Column Name</th>");
+        res.push_str("<th style=\"text-wrap: nowrap; max-width:192px; overflow:auto; text-align:left\">Type</th>");
+
+        // End the header.
+        res.push_str("</tr></thead>\n");
+
+        // Begin the body.
+        res.push_str("<tbody>\n");
+
+        for (name, field) in &self.fields {
+            res.push_str("<tr>");
+            res.push_str(
+                "<td style=\"text-align:left; max-width:192px; max-height:64px; overflow:auto\">",
+            );
+            res.push_str(&html_escape::encode_text(name));
+            res.push_str("</td>");
+            res.push_str(
+                "<td style=\"text-align:left; max-width:192px; max-height:64px; overflow:auto\">",
+            );
+            res.push_str(&html_escape::encode_text(&format!("{}", field.dtype)));
+            res.push_str("</td>");
+            res.push_str("</tr>\n");
+        }
+
+        // End the body.
+        res.push_str("</tbody>\n");
+
+        res.push_str("</table>");
+
+        res
+    }
+
+    pub fn truncated_table_html(&self) -> String {
+        // Produces a <table> HTML element.
+
+        let mut res = "<table class=\"dataframe\">\n".to_string();
+
+        // Begin the header.
+        res.push_str("<thead><tr>");
+
         for (name, field) in &self.fields {
             res.push_str(
                 "<th style=\"text-wrap: nowrap; max-width:192px; overflow:auto; text-align:left\">",
