@@ -9,7 +9,7 @@ impl IntoGroups for Series {
     fn make_groups(&self) -> DaftResult<GroupIndicesPair> {
         let s = self.as_physical()?;
         with_match_comparable_daft_types!(s.data_type(), |$T| {
-            let array = s.downcast::<$T>()?;
+            let array = s.downcast::<<$T as DaftDataType>::ArrayType>()?;
             array.make_groups()
         })
     }
