@@ -130,7 +130,7 @@ pub(crate) async fn read_csv_schema_single(
             )
             .await
         }
-        GetResult::Stream(stream, size, _) => {
+        GetResult::Stream(stream, size, ..) => {
             read_csv_schema_from_compressed_reader(
                 StreamReader::new(stream),
                 compression_codec,
@@ -197,6 +197,7 @@ where
         .escape(parse_options.escape_char)
         .comment(parse_options.comment)
         .buffer_capacity(max_bytes.unwrap_or(1 << 20).min(1 << 20))
+        .flexible(parse_options.allow_variable_columns)
         .create_reader(reader.compat());
     let (fields, read_stats) =
         infer_schema(&mut reader, None, max_bytes, parse_options.has_header).await?;
