@@ -161,6 +161,7 @@ pub struct CsvParseOptions {
     pub quote: u8,
     pub escape_char: Option<u8>,
     pub comment: Option<u8>,
+    pub allow_variable_columns: bool,
 }
 
 impl CsvParseOptions {
@@ -169,6 +170,7 @@ impl CsvParseOptions {
         delimiter: u8,
         double_quote: bool,
         quote: u8,
+        allow_variable_columns: bool,
         escape_char: Option<u8>,
         comment: Option<u8>,
     ) -> Self {
@@ -177,6 +179,7 @@ impl CsvParseOptions {
             delimiter,
             double_quote,
             quote,
+            allow_variable_columns,
             escape_char,
             comment,
         }
@@ -187,6 +190,7 @@ impl CsvParseOptions {
         delimiter: Option<char>,
         double_quote: bool,
         quote: Option<char>,
+        allow_variable_columns: bool,
         escape_char: Option<char>,
         comment: Option<char>,
     ) -> super::Result<Self> {
@@ -195,6 +199,7 @@ impl CsvParseOptions {
             char_to_byte(delimiter)?.unwrap_or(b','),
             double_quote,
             char_to_byte(quote)?.unwrap_or(b'"'),
+            allow_variable_columns,
             char_to_byte(escape_char)?,
             char_to_byte(comment)?,
         ))
@@ -229,11 +234,18 @@ impl CsvParseOptions {
     pub fn with_comment(self, comment: Option<u8>) -> Self {
         Self { comment, ..self }
     }
+
+    pub fn with_variable_columns(self, allow_variable_columns: bool) -> Self {
+        Self {
+            allow_variable_columns,
+            ..self
+        }
+    }
 }
 
 impl Default for CsvParseOptions {
     fn default() -> Self {
-        Self::new_with_defaults(true, None, true, None, None, None).unwrap()
+        Self::new_with_defaults(true, None, true, None, false, None, None).unwrap()
     }
 }
 
@@ -252,12 +264,13 @@ impl CsvParseOptions {
     /// * `comment` - The character at the start of a line that indicates that the rest of the line is a comment,
     ///   which should be ignored while parsing.
     #[new]
-    #[pyo3(signature = (has_header=true, delimiter=None, double_quote=false, quote=None, escape_char=None, comment=None))]
+    #[pyo3(signature = (has_header=true, delimiter=None, double_quote=false, quote=None, allow_variable_columns=false, escape_char=None, comment=None))]
     pub fn new(
         has_header: bool,
         delimiter: Option<char>,
         double_quote: bool,
         quote: Option<char>,
+        allow_variable_columns: bool,
         escape_char: Option<char>,
         comment: Option<char>,
     ) -> PyResult<Self> {
@@ -266,6 +279,7 @@ impl CsvParseOptions {
             delimiter,
             double_quote,
             quote,
+            allow_variable_columns,
             escape_char,
             comment,
         )?)
