@@ -4,8 +4,9 @@ use daft_core::{
     series::Series,
 };
 
-use crate::Expr;
+use crate::ExprRef;
 
+use crate::functions::FunctionExpr;
 use common_error::{DaftError, DaftResult};
 
 use super::super::FunctionEvaluator;
@@ -17,7 +18,7 @@ impl FunctionEvaluator for IsNanEvaluator {
         "is_nan"
     }
 
-    fn to_field(&self, inputs: &[Expr], schema: &Schema, _: &Expr) -> DaftResult<Field> {
+    fn to_field(&self, inputs: &[ExprRef], schema: &Schema, _: &FunctionExpr) -> DaftResult<Field> {
         match inputs {
             [data] => match data.to_field(schema) {
                 Ok(data_field) => match &data_field.dtype {
@@ -38,7 +39,7 @@ impl FunctionEvaluator for IsNanEvaluator {
         }
     }
 
-    fn evaluate(&self, inputs: &[Series], _: &Expr) -> DaftResult<Series> {
+    fn evaluate(&self, inputs: &[Series], _: &FunctionExpr) -> DaftResult<Series> {
         match inputs {
             [data] => data.is_nan(),
             _ => Err(DaftError::ValueError(format!(
