@@ -1,8 +1,10 @@
 pub mod float;
+pub mod hash;
 pub mod image;
 pub mod json;
 pub mod list;
 pub mod map;
+pub mod minhash;
 pub mod numeric;
 pub mod partitioning;
 pub mod sketch;
@@ -29,6 +31,8 @@ use self::{float::FloatExpr, uri::UriExpr};
 use common_error::DaftResult;
 use daft_core::datatypes::FieldID;
 use daft_core::{datatypes::Field, schema::Schema, series::Series};
+use hash::HashEvaluator;
+use minhash::{MinHashEvaluator, MinHashExpr};
 use serde::{Deserialize, Serialize};
 
 #[cfg(feature = "python")]
@@ -52,6 +56,8 @@ pub enum FunctionExpr {
     Python(PythonUDF),
     Partitioning(PartitioningExpr),
     Uri(UriExpr),
+    Hash,
+    MinHash(MinHashExpr),
 }
 
 pub trait FunctionEvaluator {
@@ -84,6 +90,8 @@ impl FunctionExpr {
             #[cfg(feature = "python")]
             Python(expr) => expr,
             Partitioning(expr) => expr.get_evaluator(),
+            Hash => &HashEvaluator {},
+            MinHash(_) => &MinHashEvaluator {},
         }
     }
 }
