@@ -1,7 +1,8 @@
 use common_error::{DaftError, DaftResult};
 use daft_core::{datatypes::Field, schema::Schema, series::Series};
 
-use crate::Expr;
+use crate::functions::FunctionExpr;
+use crate::ExprRef;
 
 use super::super::FunctionEvaluator;
 
@@ -12,7 +13,7 @@ impl FunctionEvaluator for AbsEvaluator {
         "abs"
     }
 
-    fn to_field(&self, inputs: &[Expr], schema: &Schema, _: &Expr) -> DaftResult<Field> {
+    fn to_field(&self, inputs: &[ExprRef], schema: &Schema, _: &FunctionExpr) -> DaftResult<Field> {
         if inputs.len() != 1 {
             return Err(DaftError::SchemaMismatch(format!(
                 "Expected 1 input arg, got {}",
@@ -29,7 +30,7 @@ impl FunctionEvaluator for AbsEvaluator {
         Ok(field)
     }
 
-    fn evaluate(&self, inputs: &[Series], _: &Expr) -> DaftResult<Series> {
+    fn evaluate(&self, inputs: &[Series], _: &FunctionExpr) -> DaftResult<Series> {
         if inputs.len() != 1 {
             return Err(DaftError::ValueError(format!(
                 "Expected 1 input arg, got {}",
