@@ -191,7 +191,9 @@ impl IOClient {
 
         let new_source = match source_type {
             SourceType::File => LocalSource::get_client().await? as Arc<dyn ObjectSource>,
-            SourceType::Http => HttpSource::get_client().await? as Arc<dyn ObjectSource>,
+            SourceType::Http => {
+                HttpSource::get_client(&self.config.http).await? as Arc<dyn ObjectSource>
+            }
             SourceType::S3 => {
                 S3LikeSource::get_client(&self.config.s3).await? as Arc<dyn ObjectSource>
             }
