@@ -1,8 +1,13 @@
-use std::{collections::HashSet, sync::Arc};
+use std::{
+    collections::{BTreeMap, HashSet},
+    sync::Arc,
+};
 
 use arrow2::io::parquet::read::schema::infer_schema_with_options;
 use common_error::DaftResult;
-use daft_core::{schema::Schema, utils::arrow::cast_array_for_daft_if_needed, Series};
+use daft_core::{
+    datatypes::Field, schema::Schema, utils::arrow::cast_array_for_daft_if_needed, Series,
+};
 use daft_dsl::ExprRef;
 use daft_io::{IOClient, IOStatsRef};
 use daft_stats::TruthValue;
@@ -191,12 +196,14 @@ impl ParquetReaderBuilder {
         uri: &str,
         io_client: Arc<daft_io::IOClient>,
         io_stats: Option<IOStatsRef>,
+        field_id_mapping: Option<Arc<BTreeMap<i32, Field>>>,
     ) -> super::Result<Self> {
         // TODO(sammy): We actually don't need this since we can do negative offsets when reading the metadata
         let size = io_client
             .single_url_get_size(uri.into(), io_stats.clone())
             .await?;
-        let metadata = read_parquet_metadata(uri, size, io_client, io_stats).await?;
+        let metadata =
+            read_parquet_metadata(uri, size, io_client, io_stats, field_id_mapping).await?;
         Ok(ParquetReaderBuilder {
             uri: uri.into(),
             metadata,
@@ -416,21 +423,28 @@ impl ParquetFileReader {
                             .map(|(i, _)| i)
                             .collect::<Vec<_>>();
 
-                        let range_readers = filtered_cols_idx
+                        let metadata = metadata.clone();
+
+                        let needed_byte_ranges = filtered_cols_idx
                             .iter()
                             .map(|i| {
                                 let c = columns.get(*i).unwrap();
                                 let (start, len) = c.byte_range();
                                 let end: u64 = start + len;
-                                let range_reader = ranges
-                                    .get_range_reader(start as usize..end as usize)
-                                    .unwrap();
-
-                                Box::pin(range_reader)
+                                start as usize..end as usize
                             })
                             .collect::<Vec<_>>();
-                        let metadata = metadata.clone();
+
+                        let ranges = ranges.clone();
+
                         let handle = tokio::task::spawn(async move {
+                            let mut range_readers = Vec::with_capacity(filtered_cols_idx.len());
+
+                            for range in needed_byte_ranges.into_iter() {
+                                let range_reader = ranges.get_range_reader(range).await?;
+                                range_readers.push(Box::pin(range_reader))
+                            }
+
                             let mut decompressed_iters =
                                 Vec::with_capacity(filtered_cols_idx.len());
                             let mut ptypes = Vec::with_capacity(filtered_cols_idx.len());
@@ -480,7 +494,7 @@ impl ParquetFileReader {
                                     num_rows,
                                 );
 
-                                let ser = (|| {
+                                let series = (|| {
                                     let mut all_arrays = vec![];
                                     let mut curr_index = 0;
 
@@ -510,7 +524,7 @@ impl ParquetFileReader {
                                         .collect::<DaftResult<Vec<Series>>>()
                                 })();
 
-                                let _ = send.send(ser);
+                                let _ = send.send(series);
                             });
                             recv.await.context(OneShotRecvSnafu {})?
                         });
@@ -592,21 +606,25 @@ impl ParquetFileReader {
                             .map(|(i, _)| i)
                             .collect::<Vec<_>>();
 
-                        let range_readers = filtered_cols_idx
+                        let needed_byte_ranges = filtered_cols_idx
                             .iter()
                             .map(|i| {
                                 let c = columns.get(*i).unwrap();
                                 let (start, len) = c.byte_range();
                                 let end: u64 = start + len;
-                                let range_reader = ranges
-                                    .get_range_reader(start as usize..end as usize)
-                                    .unwrap();
-
-                                Box::pin(range_reader)
+                                start as usize..end as usize
                             })
                             .collect::<Vec<_>>();
                         let metadata = metadata.clone();
+                        let ranges = ranges.clone();
                         let handle = tokio::task::spawn(async move {
+                            let mut range_readers = Vec::with_capacity(filtered_cols_idx.len());
+
+                            for range in needed_byte_ranges.into_iter() {
+                                let range_reader = ranges.get_range_reader(range).await?;
+                                range_readers.push(Box::pin(range_reader))
+                            }
+
                             let mut decompressed_iters =
                                 Vec::with_capacity(filtered_cols_idx.len());
                             let mut ptypes = Vec::with_capacity(filtered_cols_idx.len());
