@@ -127,7 +127,8 @@ impl GlobScanOperator {
         glob_paths: &[&str],
         file_format_config: Arc<FileFormatConfig>,
         storage_config: Arc<StorageConfig>,
-        schema_hint: Option<SchemaRef>,
+        infer_schema: bool,
+        schema: Option<SchemaRef>,
     ) -> DaftResult<Self> {
         let first_glob_path = match glob_paths.first() {
             None => Err(DaftError::ValueError(
@@ -157,73 +158,80 @@ impl GlobScanOperator {
             }
             .into()),
         }?;
-        let inferred_schema = match file_format_config.as_ref() {
-            FileFormatConfig::Parquet(ParquetSourceConfig {
-                coerce_int96_timestamp_unit,
-                field_id_mapping,
-            }) => {
-                let io_stats = IOStatsContext::new(format!(
-                    "GlobScanOperator constructor read_parquet_schema: for uri {first_filepath}"
-                ));
-                daft_parquet::read::read_parquet_schema(
-                    first_filepath.as_str(),
-                    io_client.clone(),
-                    Some(io_stats),
-                    ParquetSchemaInferenceOptions {
-                        coerce_int96_timestamp_unit: *coerce_int96_timestamp_unit,
-                    },
-                    field_id_mapping.clone(),
-                )?
-            }
-            FileFormatConfig::Csv(CsvSourceConfig {
-                delimiter,
-                has_headers,
-                double_quote,
-                quote,
-                escape_char,
-                comment,
-                ..
-            }) => {
-                let (schema, _) = daft_csv::metadata::read_csv_schema(
-                    first_filepath.as_str(),
-                    Some(CsvParseOptions::new_with_defaults(
-                        *has_headers,
-                        *delimiter,
-                        *double_quote,
-                        *quote,
-                        *escape_char,
-                        *comment,
-                    )?),
-                    None,
-                    io_client,
-                    Some(io_stats),
-                )?;
-                schema
-            }
-            FileFormatConfig::Json(_) => daft_json::schema::read_json_schema(
-                first_filepath.as_str(),
-                None,
-                None,
-                io_client,
-                Some(io_stats),
-            )?,
-            #[cfg(feature = "python")]
-            FileFormatConfig::Database(_) => {
-                return Err(DaftError::ValueError(
-                    "Cannot glob a database source".to_string(),
-                ))
-            }
-            #[cfg(feature = "python")]
-            FileFormatConfig::PythonFunction => {
-                return Err(DaftError::ValueError(
-                    "Cannot glob a PythonFunction source".to_string(),
-                ))
-            }
-        };
 
-        let schema = match schema_hint {
-            None => Arc::new(inferred_schema),
-            Some(schema_hint) => Arc::new(inferred_schema.apply_hints(&schema_hint)?),
+        let schema = match infer_schema {
+            true => {
+                let inferred_schema = match file_format_config.as_ref() {
+                    FileFormatConfig::Parquet(ParquetSourceConfig {
+                        coerce_int96_timestamp_unit,
+                        field_id_mapping,
+                    }) => {
+                        let io_stats = IOStatsContext::new(format!(
+                            "GlobScanOperator constructor read_parquet_schema: for uri {first_filepath}"
+                        ));
+                        daft_parquet::read::read_parquet_schema(
+                            first_filepath.as_str(),
+                            io_client.clone(),
+                            Some(io_stats),
+                            ParquetSchemaInferenceOptions {
+                                coerce_int96_timestamp_unit: *coerce_int96_timestamp_unit,
+                            },
+                            field_id_mapping.clone(),
+                        )?
+                    }
+                    FileFormatConfig::Csv(CsvSourceConfig {
+                        delimiter,
+                        has_headers,
+                        double_quote,
+                        quote,
+                        escape_char,
+                        comment,
+                        allow_variable_columns,
+                        ..
+                    }) => {
+                        let (schema, _) = daft_csv::metadata::read_csv_schema(
+                            first_filepath.as_str(),
+                            Some(CsvParseOptions::new_with_defaults(
+                                *has_headers,
+                                *delimiter,
+                                *double_quote,
+                                *quote,
+                                *allow_variable_columns,
+                                *escape_char,
+                                *comment,
+                            )?),
+                            None,
+                            io_client,
+                            Some(io_stats),
+                        )?;
+                        schema
+                    }
+                    FileFormatConfig::Json(_) => daft_json::schema::read_json_schema(
+                        first_filepath.as_str(),
+                        None,
+                        None,
+                        io_client,
+                        Some(io_stats),
+                    )?,
+                    #[cfg(feature = "python")]
+                    FileFormatConfig::Database(_) => {
+                        return Err(DaftError::ValueError(
+                            "Cannot glob a database source".to_string(),
+                        ))
+                    }
+                    #[cfg(feature = "python")]
+                    FileFormatConfig::PythonFunction => {
+                        return Err(DaftError::ValueError(
+                            "Cannot glob a PythonFunction source".to_string(),
+                        ))
+                    }
+                };
+                match schema {
+                    Some(hint) => Arc::new(inferred_schema.apply_hints(&hint)?),
+                    None => Arc::new(inferred_schema),
+                }
+            }
+            false => schema.expect("Schema must be provided if infer_schema is false"),
         };
 
         Ok(Self {
