@@ -1,7 +1,7 @@
 use pyo3::{prelude::*, types::PyTuple, AsPyPointer};
 use serde::{Deserialize, Serialize};
 
-use crate::py_object_serde::{deserialize_py_object, serialize_py_object};
+use common_py_serde::{deserialize_py_object, serialize_py_object};
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
 struct PyObjectSerializableWrapper(
@@ -119,14 +119,16 @@ pub mod pylib {
             glob_path: Vec<&str>,
             file_format_config: PyFileFormatConfig,
             storage_config: PyStorageConfig,
-            schema_hint: Option<PySchema>,
+            infer_schema: bool,
+            schema: Option<PySchema>,
         ) -> PyResult<Self> {
             py.allow_threads(|| {
                 let operator = Arc::new(GlobScanOperator::try_new(
                     glob_path.as_slice(),
                     file_format_config.into(),
                     storage_config.into(),
-                    schema_hint.map(|s| s.schema),
+                    infer_schema,
+                    schema.map(|s| s.schema),
                 )?);
                 Ok(ScanOperatorHandle {
                     scan_op: ScanOperatorRef(operator),
@@ -309,8 +311,8 @@ pub mod pylib {
             file: String,
             file_format: PyFileFormatConfig,
             schema: PySchema,
-            num_rows: i64,
             storage_config: PyStorageConfig,
+            num_rows: Option<i64>,
             size_bytes: Option<u64>,
             pushdowns: Option<PyPushdowns>,
             partition_values: Option<PyTable>,
@@ -329,8 +331,8 @@ pub mod pylib {
                 assert_eq!(boolean.len(), 1);
                 let value = boolean.get(0);
                 match value {
-                    Some(false) => return Ok(None),
-                    None | Some(true) => {}
+                    None | Some(false) => return Ok(None),
+                    Some(true) => {}
                 }
             }
             // TODO(Clark): Filter out scan tasks with pushed down filters + table stats?
@@ -343,15 +345,26 @@ pub mod pylib {
             let statistics = stats
                 .map(|s| TableStatistics::from_stats_table(&s.table))
                 .transpose()?;
-            let data_source = DataFileSource::CatalogDataFile {
-                path: file,
-                chunk_spec: None,
-                size_bytes,
-                metadata: TableMetadata {
-                    length: num_rows as usize,
+
+            let table_metadata = num_rows.map(|n| TableMetadata { length: n as usize });
+
+            let data_source = match table_metadata {
+                None => DataFileSource::AnonymousDataFile {
+                    path: file,
+                    chunk_spec: None,
+                    size_bytes,
+                    metadata: None,
+                    partition_spec: Some(pspec),
+                    statistics,
+                },
+                Some(tm) => DataFileSource::CatalogDataFile {
+                    path: file,
+                    chunk_spec: None,
+                    size_bytes,
+                    metadata: tm,
+                    partition_spec: pspec,
+                    statistics,
                 },
-                partition_spec: pspec,
-                statistics,
             };
 
             let scan_task = ScanTask::new(
