@@ -494,7 +494,7 @@ def test_create_dataframe_csv_custom_delimiter(valid_data: list[dict[str, float]
 
 
 @pytest.mark.parametrize("use_native_downloader", [True, False])
-def test_create_dataframe_csv_specify_schema(valid_data: list[dict[str, float]], use_native_downloader) -> None:
+def test_create_dataframe_csv_provided_schema(valid_data: list[dict[str, float]], use_native_downloader) -> None:
     with create_temp_filename() as fname:
         with open(fname, "w") as f:
             header = list(valid_data[0].keys())
@@ -506,24 +506,30 @@ def test_create_dataframe_csv_specify_schema(valid_data: list[dict[str, float]],
         df = daft.read_csv(
             fname,
             delimiter="\t",
-            schema_hints={
-                "sepal_length": DataType.float32(),
-                "sepal_width": DataType.float32(),
-                "petal_length": DataType.float32(),
-                "petal_width": DataType.float32(),
+            infer_schema=False,
+            schema={
+                "s_length": DataType.float32(),
+                "s_width": DataType.string(),
+                "p_length": DataType.float32(),
+                "p_width": DataType.string(),
                 "variety": DataType.string(),
             },
             use_native_downloader=use_native_downloader,
         )
-        assert df.column_names == COL_NAMES
+        assert df.column_names == ["s_length", "s_width", "p_length", "p_width", "variety"]
+        assert df.schema()["s_length"].dtype == DataType.float32()
+        assert df.schema()["s_width"].dtype == DataType.string()
+        assert df.schema()["p_length"].dtype == DataType.float32()
+        assert df.schema()["p_width"].dtype == DataType.string()
+        assert df.schema()["variety"].dtype == DataType.string()
 
         pd_df = df.to_pandas()
-        assert list(pd_df.columns) == COL_NAMES
+        assert list(pd_df.columns) == ["s_length", "s_width", "p_length", "p_width", "variety"]
         assert len(pd_df) == len(valid_data)
 
 
 @pytest.mark.parametrize("use_native_downloader", [True, False])
-def test_create_dataframe_csv_specify_schema_no_headers(
+def test_create_dataframe_csv_provided_schema_no_headers(
     valid_data: list[dict[str, float]], use_native_downloader
 ) -> None:
     with create_temp_filename() as fname:
@@ -533,25 +539,26 @@ def test_create_dataframe_csv_specify_schema_no_headers(
             writer.writerows([[item[col] for col in header] for item in valid_data])
             f.flush()
 
-        schema_hints_for_csv_without_headers = {
-            "column_1": DataType.float64(),
-            "column_2": DataType.float64(),
-            "column_3": DataType.float64(),
-            "column_4": DataType.float64(),
-            "column_5": DataType.string(),
+        schema_for_csv_without_headers = {
+            "c_1": DataType.float64(),
+            "c_2": DataType.float64(),
+            "c_3": DataType.float64(),
+            "c_4": DataType.float64(),
+            "c_5": DataType.string(),
         }
 
         df = daft.read_csv(
             fname,
             delimiter="\t",
-            schema_hints=schema_hints_for_csv_without_headers,
+            infer_schema=False,
+            schema=schema_for_csv_without_headers,
             has_headers=False,
             use_native_downloader=use_native_downloader,
         )
-        assert df.column_names == list(schema_hints_for_csv_without_headers.keys())
+        assert df.column_names == list(schema_for_csv_without_headers.keys())
 
         pd_df = df.to_pandas()
-        assert list(pd_df.columns) == list(schema_hints_for_csv_without_headers.keys())
+        assert list(pd_df.columns) == list(schema_for_csv_without_headers.keys())
         assert len(pd_df) == len(valid_data)
 
 
@@ -568,7 +575,8 @@ def test_create_dataframe_csv_schema_hints_partial(valid_data: list[dict[str, fl
         df = daft.read_csv(
             fname,
             delimiter="\t",
-            schema_hints={
+            infer_schema=True,
+            schema={
                 "sepal_length": DataType.float64(),
                 "sepal_width": DataType.float64(),
             },
@@ -596,7 +604,8 @@ def test_create_dataframe_csv_schema_hints_override_types(
         df = daft.read_csv(
             fname,
             delimiter="\t",
-            schema_hints={
+            infer_schema=True,
+            schema={
                 "sepal_length": DataType.string(),  # Override the inferred float64 type to string
             },
             use_native_downloader=use_native_downloader,
@@ -626,7 +635,8 @@ def test_create_dataframe_csv_schema_hints_ignore_random_hint(
         df = daft.read_csv(
             fname,
             delimiter="\t",
-            schema_hints={
+            infer_schema=True,
+            schema={
                 "foo": DataType.string(),  # Random column name that is not in the table
             },
             use_native_downloader=use_native_downloader,
@@ -638,6 +648,27 @@ def test_create_dataframe_csv_schema_hints_ignore_random_hint(
         assert len(pd_df) == len(valid_data)
 
 
+@pytest.mark.parametrize("use_native_downloader", [True, False])
+def test_create_dataframe_csv_without_schema_or_inference(
+    valid_data: list[dict[str, float]], use_native_downloader
+) -> None:
+    with create_temp_filename() as fname:
+        with open(fname, "w") as f:
+            header = list(valid_data[0].keys())
+            writer = csv.writer(f, delimiter="\t")
+            writer.writerow(header)
+            writer.writerows([[item[col] for col in header] for item in valid_data])
+            f.flush()
+
+        with pytest.raises(ValueError):
+            daft.read_csv(
+                fname,
+                delimiter="\t",
+                infer_schema=False,
+                use_native_downloader=use_native_downloader,
+            )
+
+
 ###
 # JSON tests
 ###
@@ -712,7 +743,7 @@ def test_create_dataframe_json_https() -> None:
 
 
 @pytest.mark.parametrize("use_native_downloader", [True, False])
-def test_create_dataframe_json_specify_schema(valid_data: list[dict[str, float]], use_native_downloader) -> None:
+def test_create_dataframe_json_provided_schema(valid_data: list[dict[str, float]], use_native_downloader) -> None:
     with create_temp_filename() as fname:
         with open(fname, "w") as f:
             for data in valid_data:
@@ -722,7 +753,8 @@ def test_create_dataframe_json_specify_schema(valid_data: list[dict[str, float]]
 
         df = daft.read_json(
             fname,
-            schema_hints={
+            infer_schema=False,
+            schema={
                 "sepal_length": DataType.float32(),
                 "sepal_width": DataType.float32(),
                 "petal_length": DataType.float32(),
@@ -738,7 +770,7 @@ def test_create_dataframe_json_specify_schema(valid_data: list[dict[str, float]]
         assert len(pd_df) == len(valid_data)
 
 
-def test_create_dataframe_json_schema_hints_partial(valid_data: list[dict[str, float]]) -> None:
+def test_create_dataframe_json_partial_schema(valid_data: list[dict[str, float]]) -> None:
     with create_temp_filename() as fname:
         with open(fname, "w") as f:
             for data in valid_data:
@@ -748,7 +780,8 @@ def test_create_dataframe_json_schema_hints_partial(valid_data: list[dict[str, f
 
         df = daft.read_json(
             fname,
-            schema_hints={
+            infer_schema=True,
+            schema={
                 "sepal_length": DataType.float64(),
                 "sepal_width": DataType.float64(),
             },
@@ -760,7 +793,7 @@ def test_create_dataframe_json_schema_hints_partial(valid_data: list[dict[str, f
         assert len(pd_df) == len(valid_data)
 
 
-def test_create_dataframe_json_schema_hints_override_types(valid_data: list[dict[str, float]]) -> None:
+def test_create_dataframe_json_schema_override_types(valid_data: list[dict[str, float]]) -> None:
     with create_temp_filename() as fname:
         with open(fname, "w") as f:
             for data in valid_data:
@@ -770,7 +803,8 @@ def test_create_dataframe_json_schema_hints_override_types(valid_data: list[dict
 
         df = daft.read_json(
             fname,
-            schema_hints={
+            infer_schema=True,
+            schema={
                 "sepal_length": DataType.string(),  # Override the inferred float64 type to string
             },
         )
@@ -794,7 +828,8 @@ def test_create_dataframe_json_schema_hints_ignore_random_hint(valid_data: list[
 
         df = daft.read_json(
             fname,
-            schema_hints={
+            infer_schema=True,
+            schema={
                 "foo": DataType.string(),  # Random column name that is not in the table
             },
         )
@@ -823,7 +858,8 @@ def test_create_dataframe_json_schema_hints_two_files() -> None:
         # With schema hints, bar2 should be included
         df = daft.read_json(
             [fname, fname2],
-            schema_hints={"foo": DataType.struct({"bar": DataType.string(), "bar2": DataType.string()})},
+            infer_schema=True,
+            schema={"foo": DataType.struct({"bar": DataType.string(), "bar2": DataType.string()})},
         )
         assert df.schema()["foo"].dtype == DataType.struct({"bar": DataType.string(), "bar2": DataType.string()})
 
