@@ -13,6 +13,10 @@ def skip_invalid_join_strategies(join_strategy, join_type):
         pytest.skip("Sort merge currently only supports inner joins")
     elif join_strategy == "broadcast" and join_type == "outer":
         pytest.skip("Broadcast join does not support outer joins")
+    elif join_strategy == "broadcast" and join_type == "anti":
+        pytest.skip("Broadcast join does not support anti joins")
+    elif join_strategy == "broadcast" and join_type == "semi":
+        pytest.skip("Broadcast join does not support semi joins")
 
 
 def test_invalid_join_strategies(make_df):
@@ -31,6 +35,23 @@ def test_invalid_join_strategies(make_df):
         df.join(df, on="A", strategy="broadcast", how="outer")
 
 
+def test_columns_after_join(make_df):
+    df1 = make_df(
+        {
+            "A": [1, 2, 3],
+        },
+    )
+
+    df2 = make_df({"A": [1, 2, 3], "B": [1, 2, 3]})
+
+    joined_df1 = df1.join(df2, left_on="A", right_on="B")
+    joined_df2 = df1.join(df2, left_on="A", right_on="A")
+
+    assert set(joined_df1.schema().column_names()) == set(["A", "B", "right.A"])
+
+    assert set(joined_df2.schema().column_names()) == set(["A", "B"])
+
+
 @pytest.mark.parametrize("n_partitions", [1, 2, 4])
 @pytest.mark.parametrize(
     "join_strategy",
@@ -703,3 +724,56 @@ def test_join_null_type_column(join_strategy, join_type, make_df):
 
     with pytest.raises((ExpressionTypeError, ValueError)):
         daft_df.join(daft_df2, on="id", how=join_type, strategy=join_strategy)
+
+
+@pytest.mark.parametrize("repartition_nparts", [1, 2, 4])
+@pytest.mark.parametrize(
+    "join_strategy",
+    [None, "hash", "sort_merge", "sort_merge_aligned_boundaries", "broadcast"],
+    indirect=True,
+)
+@pytest.mark.parametrize(
+    "join_type,expected",
+    [
+        (
+            "semi",
+            {
+                "id": [2, 3],
+                "values_left": ["b1", "c1"],
+            },
+        ),
+        (
+            "anti",
+            {
+                "id": [1, None],
+                "values_left": ["a1", "d1"],
+            },
+        ),
+    ],
+)
+def test_join_semi_anti(join_strategy, join_type, expected, make_df, repartition_nparts):
+    skip_invalid_join_strategies(join_strategy, join_type)
+
+    daft_df1 = make_df(
+        {
+            "id": [1, 2, 3, None],
+            "values_left": ["a1", "b1", "c1", "d1"],
+        },
+        repartition=repartition_nparts,
+    )
+    daft_df2 = make_df(
+        {
+            "id": [2, 2, 3, 4],
+            "values_right": ["a2", "b2", "c2", "d2"],
+        },
+        repartition=repartition_nparts,
+    )
+    daft_df = (
+        daft_df1.with_column("id", daft_df1["id"].cast(DataType.int64()))
+        .join(daft_df2, on="id", how=join_type, strategy=join_strategy)
+        .sort(["id", "values_left"])
+    ).select("id", "values_left")
+
+    assert sort_arrow_table(pa.Table.from_pydict(daft_df.to_pydict()), "id") == sort_arrow_table(
+        pa.Table.from_pydict(expected), "id"
+    )
