@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import math
 import operator as ops
 
 import pytest
@@ -138,6 +139,20 @@ def test_log10(unary_data_fixture):
     )
 
 
+@pytest.mark.parametrize(
+    "base",
+    [2, 10, 100, math.e],
+)
+def test_log(unary_data_fixture, base: float):
+    arg = unary_data_fixture
+    assert_typing_resolve_vs_runtime_behavior(
+        data=(unary_data_fixture,),
+        expr=col(arg.name()).log(base=base),
+        run_kernel=lambda: arg.log(base=base),
+        resolvable=is_numeric(arg.datatype()),
+    )
+
+
 def test_ln(unary_data_fixture):
     arg = unary_data_fixture
     assert_typing_resolve_vs_runtime_behavior(
@@ -172,6 +187,16 @@ def test_trigonometry(fun: str, unary_data_fixture):
     )
 
 
+def test_atan2(binary_data_fixture):
+    lhs, rhs = binary_data_fixture
+    assert_typing_resolve_vs_runtime_behavior(
+        data=binary_data_fixture,
+        expr=col(lhs.name()).arctan2(col(rhs.name())),
+        run_kernel=lambda: lhs.arctan2(rhs),
+        resolvable=is_numeric(lhs.datatype()) and is_numeric(rhs.datatype()),
+    )
+
+
 def test_exp(unary_data_fixture):
     arg = unary_data_fixture
     assert_typing_resolve_vs_runtime_behavior(
