@@ -2,7 +2,6 @@ from __future__ import annotations
 
 import pytest
 
-from daft.datatype import DataType
 from daft.expressions import col
 from tests.expressions.typing.conftest import assert_typing_resolve_vs_runtime_behavior
 
@@ -14,6 +13,7 @@ from tests.expressions.typing.conftest import assert_typing_resolve_vs_runtime_b
         pytest.param(lambda x: x.dt.month(), id="month"),
         pytest.param(lambda x: x.dt.year(), id="year"),
         pytest.param(lambda x: x.dt.day_of_week(), id="day_of_week"),
+        pytest.param(lambda x: x.dt.date(), id="date"),
     ],
 )
 def test_dt_extraction_ops(unary_data_fixture, op):
@@ -22,5 +22,5 @@ def test_dt_extraction_ops(unary_data_fixture, op):
         data=(unary_data_fixture,),
         expr=op(col(arg.name())),
         run_kernel=lambda: op(arg),
-        resolvable=arg.datatype() == DataType.date(),
+        resolvable=arg.datatype()._is_temporal_type(),
     )
