@@ -1,12 +1,12 @@
 from __future__ import annotations
 
 from daft.expressions import col
-from daft.table import Table
+from daft.table import MicroPartition
 
 
 def test_pyobjects_blackbox_kernels() -> None:
     objects = [object(), None, object()]
-    table = Table.from_pydict({"keys": [0, 1, 2], "objs": objects})
+    table = MicroPartition.from_pydict({"keys": [0, 1, 2], "objs": objects})
     # Head.
     assert table.head(2).to_pydict()["objs"] == objects[:2]
     # Filter.
@@ -16,7 +16,7 @@ def test_pyobjects_blackbox_kernels() -> None:
 def test_nested_blackbox_kernels() -> None:
     structs = [{"a": 1, "b": 2}, None, {"a": 3}]
     lists = [[1, 2], None, [3]]
-    table = Table.from_pydict({"keys": [0, 1, 2], "structs": structs, "lists": lists})
+    table = MicroPartition.from_pydict({"keys": [0, 1, 2], "structs": structs, "lists": lists})
     # pyarrow fills in implicit field-internal Nones on a .to_pylist() conversion.
     structs[2]["b"] = None
     # Head.
